A simulated data set to illustrate the Functional BART method. Data contains four 'x' covariates; each pair is simulated from bivariate Gaussians with moderate correlation and unit variance. Each observation has one corresponding time point at which it is observed, randomly chosen from eight discrete time points.
Function values are calculated as f(x,t) = g(x1,x2) * cos(t + 2 * pi * h(x2,x3)) where g() and h() are sums of the covariates.
This configuration simulates both amplitude change and phase shift for the underlying function.
The functional response, observed with noise.
The time point for each observation.
The functional response without noise.
Residual error.
The four covariates, simulated as pairs of bivariate Gaussians.
A unique identifier for each observation.
Train/test set indicators for a random 70-30 split.